searchData={"content_type":"text/markdown","items":[{"doc":"ex_fuzzywuzzy is a fuzzy string matching library that uses a customizable measure\nto calculate a distance ratio\n\n\n\nChoose the ratio function which fits best your needs among the available, \nproviding the two strings to be matched and - if needed - overwriting options \nover the configured ones.\n\nAvailable methods are:\n- Simple ratio\n- Quick ratio\n- Partial ratio\n- Token sort ratio\n- Partial token sort ratio\n- Token set ratio\n- Partial token set ratio\n- Best score ratio\n\nAvailable options are:\n- Similarity function (Levenshtein and Jaro-Winkler provided in library)\n- Case sensitiveness of match\n- Decimal precision of output score\n\nHere are some examples.\n\n#","ref":"ExFuzzywuzzy.html","title":"ExFuzzywuzzy","type":"module"},{"doc":"```elixir\niex> ExFuzzywuzzy.ratio(\"this is a test\", \"this is a test!\")\n96.55\n```\n\n#","ref":"ExFuzzywuzzy.html#module-simple-ratio","title":"Simple ratio - ExFuzzywuzzy","type":"module"},{"doc":"```elixir\niex> ExFuzzywuzzy.quick_ratio(\"this is a test\", \"this is a test!\")\n100.0\n```\n\n#","ref":"ExFuzzywuzzy.html#module-quick-ratio","title":"Quick ratio - ExFuzzywuzzy","type":"module"},{"doc":"```elixir\niex> ExFuzzywuzzy.partial_ratio(\"this is a test\", \"this is a test!\")\n100.0\n```\n\n#","ref":"ExFuzzywuzzy.html#module-partial-ratio","title":"Partial ratio - ExFuzzywuzzy","type":"module"},{"doc":"```elixir\niex> ExFuzzywuzzy.best_score_ratio(\"this is a test\", \"this is a test!\")\n{:quick, 100.0}\n```","ref":"ExFuzzywuzzy.html#module-best-score-ratio","title":"Best Score ratio - ExFuzzywuzzy","type":"module"},{"doc":"Calculates the ratio between the strings using various methods, returning the best score and algorithm","ref":"ExFuzzywuzzy.html#best_score_ratio/4","title":"ExFuzzywuzzy.best_score_ratio/4","type":"function"},{"doc":"Calculates the partial ratio between two strings, that is the ratio between\nthe best matching m-length substrings\n\n```elixir\niex> partial_ratio(\"this is a test\", \"this is a test!\")\n100.0\n\niex> partial_ratio(\"yankees\", \"new york yankees\")\n100.0\n```","ref":"ExFuzzywuzzy.html#partial_ratio/3","title":"ExFuzzywuzzy.partial_ratio/3","type":"function"},{"doc":"Like token set ratio, but a partial ratio - instead a full one - is applied\n\n```elixir\niex> partial_token_set_ratio(\"grizzly was a bear\", \"a grizzly inside a box\")\n100.0\n\niex> partial_token_set_ratio(\"grizzly was a bear\", \"be what you wear\")\n43.75\n```","ref":"ExFuzzywuzzy.html#partial_token_set_ratio/3","title":"ExFuzzywuzzy.partial_token_set_ratio/3","type":"function"},{"doc":"Like token sort ratio, but a partial ratio - instead of a standard one - is applied\n\n```elixir\niex> partial_token_sort_ratio(\"fuzzy wuzzy was a bear\", \"wuzzy fuzzy was a bear\")\n100.0\n\niex> partial_token_sort_ratio(\"fuzzy was a bear\", \"fuzzy fuzzy was a bear\")\n81.25\n```","ref":"ExFuzzywuzzy.html#partial_token_sort_ratio/3","title":"ExFuzzywuzzy.partial_token_sort_ratio/3","type":"function"},{"doc":"Process a list of strings, finding the best match on a string reference. Not implemented yet","ref":"ExFuzzywuzzy.html#process/3","title":"ExFuzzywuzzy.process/3","type":"function"},{"doc":"Like standard ratio, but ignores any non-alphanumeric character\n\n```elixir\niex> quick_ratio(\"this is a test\", \"this is a test!\")\n100.0\n```","ref":"ExFuzzywuzzy.html#quick_ratio/3","title":"ExFuzzywuzzy.quick_ratio/3","type":"function"},{"doc":"Calculates the standard ratio between two strings as a percentage.\nIt demands the calculus to the chosen measure, standardizing the produced output\n\n```elixir\niex> ratio(\"this is a test\", \"this is a test!\")\n96.55\n```","ref":"ExFuzzywuzzy.html#ratio/3","title":"ExFuzzywuzzy.ratio/3","type":"function"},{"doc":"Calculates the token set ratio between two strings, that is the ratio calculated\nafter tokenizing each string, splitting in two sets (a set with fully matching tokens,\na set with other tokens), then sorting on set membership and alphabetically\n\n```elixir\niex> token_set_ratio(\"fuzzy was a bear\", \"fuzzy fuzzy was a bear\")\n100.0\n\niex> token_set_ratio(\"fuzzy was a bear\", \"muzzy wuzzy was a bear\")\n78.95\n```","ref":"ExFuzzywuzzy.html#token_set_ratio/3","title":"ExFuzzywuzzy.token_set_ratio/3","type":"function"},{"doc":"Calculates the token sort ratio between two strings, that is the ratio calculated\nafter tokenizing and sorting alphabetically each string\n\n```elixir\niex> token_sort_ratio(\"fuzzy wuzzy was a bear\", \"wuzzy fuzzy was a bear\")\n100.0\n\niex> token_sort_ratio(\"fuzzy muzzy was a bear\", \"wuzzy fuzzy was a bear\")\n77.27\n```","ref":"ExFuzzywuzzy.html#token_sort_ratio/3","title":"ExFuzzywuzzy.token_sort_ratio/3","type":"function"},{"doc":"Weighted ratio. Not implemented yet","ref":"ExFuzzywuzzy.html#weighted_ratio/3","title":"ExFuzzywuzzy.weighted_ratio/3","type":"function"},{"doc":"Ratio methods available that match the full string","ref":"ExFuzzywuzzy.html#t:full_match_method/0","title":"ExFuzzywuzzy.full_match_method/0","type":"type"},{"doc":"Configurable runtime option types","ref":"ExFuzzywuzzy.html#t:fuzzywuzzy_option/0","title":"ExFuzzywuzzy.fuzzywuzzy_option/0","type":"type"},{"doc":"Configurable runtime options for ratio","ref":"ExFuzzywuzzy.html#t:fuzzywuzzy_options/0","title":"ExFuzzywuzzy.fuzzywuzzy_options/0","type":"type"},{"doc":"All ratio methods available","ref":"ExFuzzywuzzy.html#t:match_method/0","title":"ExFuzzywuzzy.match_method/0","type":"type"},{"doc":"Ratio methods available that works on the best matching substring","ref":"ExFuzzywuzzy.html#t:partial_match_method/0","title":"ExFuzzywuzzy.partial_match_method/0","type":"type"},{"doc":"Ratio calculator-like signature","ref":"ExFuzzywuzzy.html#t:ratio_calculator/0","title":"ExFuzzywuzzy.ratio_calculator/0","type":"type"},{"doc":"Helper module for the calculus of the longest common substring algorithm between two strings","ref":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring.html","title":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring","type":"module"},{"doc":"Calculates the longest common substring between two strings, returning a tuple containing\nthe matched substring, the length of the substring itself, the starting index of the matches\non the left and on the right.","ref":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring.html#lcs/2","title":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring.lcs/2","type":"function"},{"doc":"The data collected applying partial matching algorithm","ref":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring.html#t:t/0","title":"ExFuzzywuzzy.Algorithms.LongestCommonSubstring.t/0","type":"type"},{"doc":"Implementation for the partial matching algorithms used by the library interface.\nThe model defined is linked to the calling ratio functions, making no sense to be used externally","ref":"ExFuzzywuzzy.Algorithms.PartialMatch.html","title":"ExFuzzywuzzy.Algorithms.PartialMatch","type":"module"},{"doc":"Calculates a list of string pairs which are the best matching substrings extracted from the provided ones","ref":"ExFuzzywuzzy.Algorithms.PartialMatch.html#matching_blocks/2","title":"ExFuzzywuzzy.Algorithms.PartialMatch.matching_blocks/2","type":"function"},{"doc":"","ref":"ExFuzzywuzzy.Algorithms.PartialMatch.html#matching_blocks/4","title":"ExFuzzywuzzy.Algorithms.PartialMatch.matching_blocks/4","type":"function"},{"doc":"The position of a grapheme in a string","ref":"ExFuzzywuzzy.Algorithms.PartialMatch.html#t:index/0","title":"ExFuzzywuzzy.Algorithms.PartialMatch.index/0","type":"type"},{"doc":"The data collected applying partial matching algorithm","ref":"ExFuzzywuzzy.Algorithms.PartialMatch.html#t:t/0","title":"ExFuzzywuzzy.Algorithms.PartialMatch.t/0","type":"type"},{"doc":"Defines the `ExFuzzywuzzy.Similarity` behaviour for implementing a similarity calculator.\n\nA custom calculator expects two strings and calculates the similarity between them\nas a floating-point decimal between 0 and 1.\n\nOut-of-the-box, ExFuzzywuzzy provides Levenshtein and Jaro algorithms.","ref":"ExFuzzywuzzy.Similarity.html","title":"ExFuzzywuzzy.Similarity","type":"behaviour"},{"doc":"","ref":"ExFuzzywuzzy.Similarity.html#c:calculate/2","title":"ExFuzzywuzzy.Similarity.calculate/2","type":"callback"},{"doc":"Implements the similarity calculus basing on the\n[Jaro-Winkler method](https://en.wikipedia.org/wiki/Jaro%E2%80%93Winkler_distance)","ref":"ExFuzzywuzzy.Similarity.JaroWinkler.html","title":"ExFuzzywuzzy.Similarity.JaroWinkler","type":"module"},{"doc":"The Jaro-Winkler\nCalculus delegates to Elixir standard library implementation","ref":"ExFuzzywuzzy.Similarity.JaroWinkler.html#calculate/2","title":"ExFuzzywuzzy.Similarity.JaroWinkler.calculate/2","type":"function"},{"doc":"Implements the similarity calculus basing on the\n[Levenshtein distance](https://en.wikipedia.org/wiki/Levenshtein_distance)","ref":"ExFuzzywuzzy.Similarity.Levenshtein.html","title":"ExFuzzywuzzy.Similarity.Levenshtein","type":"module"},{"doc":"The Levenshtein distance is calculated as the minimum number of edits in order to transition from one string to the other\nImplementation follows [Hjelmqvist algorithm](https://www.codeproject.com/Articles/13525/Fast-memory-efficient-Levenshtein-algorithm-2)","ref":"ExFuzzywuzzy.Similarity.Levenshtein.html#calculate/2","title":"ExFuzzywuzzy.Similarity.Levenshtein.calculate/2","type":"function"},{"doc":"# ExFuzzywuzzy\n[![CI](https://github.com/primait/ex_fuzzywuzzy/actions/workflows/ci.yml/badge.svg)](https://github.com/primait/ex_fuzzywuzzy/actions/workflows/ci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/ex_fuzzywuzzy.svg)](https://hex.pm/packages/ex_fuzzywuzzy)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ex_fuzzywuzzy/)\n[![Total Download](https://img.shields.io/hexpm/dt/ex_fuzzywuzzy.svg)](https://hex.pm/packages/ex_fuzzywuzzy)\n[![License](https://img.shields.io/hexpm/l/ex_fuzzywuzzy.svg)](https://hex.pm/packages/ex_fuzzywuzzy)\n[![Last Updated](https://img.shields.io/github/last-commit/primait/ex_fuzzywuzzy/master)](https://github.com/primait/ex_fuzzywuzzy/commits/master)\n\nExFuzzyWuzzy is a fuzzy string matching library that provides many ways of calculating\na matching ratio between two strings, starting from a similarity function which can be\nbased on Levenshtein or Jaro-Winkler or a custom one.\n\nThe library is an Elixir port of SeatGeek's [fuzzywuzzy](https://github.com/seatgeek/fuzzywuzzy).","ref":"readme.html","title":"ExFuzzywuzzy","type":"extras"},{"doc":"To install ExFuzzyWuzzy, just add an entry to your `mix.exs`:\n```elixir\ndef deps do\n  [\n    {:ex_fuzzywuzzy, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ExFuzzywuzzy","type":"extras"},{"doc":"<!--MDOC !-->\n\nChoose the ratio function which fits best your needs among the available, \nproviding the two strings to be matched and - if needed - overwriting options \nover the configured ones.\n\nAvailable methods are:\n- Simple ratio\n- Quick ratio\n- Partial ratio\n- Token sort ratio\n- Partial token sort ratio\n- Token set ratio\n- Partial token set ratio\n- Best score ratio\n\nAvailable options are:\n- Similarity function (Levenshtein and Jaro-Winkler provided in library)\n- Case sensitiveness of match\n- Decimal precision of output score\n\nHere are some examples.\n\n#","ref":"readme.html#usage","title":"Usage - ExFuzzywuzzy","type":"extras"},{"doc":"```elixir\niex> ExFuzzywuzzy.ratio(\"this is a test\", \"this is a test!\")\n96.55\n```\n\n#","ref":"readme.html#simple-ratio","title":"Simple ratio - ExFuzzywuzzy","type":"extras"},{"doc":"```elixir\niex> ExFuzzywuzzy.quick_ratio(\"this is a test\", \"this is a test!\")\n100.0\n```\n\n#","ref":"readme.html#quick-ratio","title":"Quick ratio - ExFuzzywuzzy","type":"extras"},{"doc":"```elixir\niex> ExFuzzywuzzy.partial_ratio(\"this is a test\", \"this is a test!\")\n100.0\n```\n\n#","ref":"readme.html#partial-ratio","title":"Partial ratio - ExFuzzywuzzy","type":"extras"},{"doc":"```elixir\niex> ExFuzzywuzzy.best_score_ratio(\"this is a test\", \"this is a test!\")\n{:quick, 100.0}\n```\n<!--MDOC !-->","ref":"readme.html#best-score-ratio","title":"Best Score ratio - ExFuzzywuzzy","type":"extras"},{"doc":"Thank your for considering helping with this project. Please see\n`CONTRIBUTING.md` file for contributing to this project.","ref":"readme.html#contributing","title":"Contributing - ExFuzzywuzzy","type":"extras"},{"doc":"MIT License. Copyright (c) 2015-2024 Prima.it","ref":"readme.html#license","title":"License - ExFuzzywuzzy","type":"extras"},{"doc":"# Contributing\n\nWhen contributing to this repository, please first discuss the change you wish to make via issue,\nemail, or any other method with the owners of this repository before making a change.","ref":"contributing.html","title":"Contributing","type":"extras"},{"doc":"1. Ensure any install or build dependencies are removed before the end of the layer when doing a\n   build.\n2. Update the README.md with details of any structural change, this includes new environment\n   variables, exposed ports, useful file locations and container parameters.\n3. Increase the version numbers in any examples files and the README.md to the new version that this\n   Pull Request would represent. The versioning scheme we use is [SemVer](http://semver.org/).\n4. Before submitting a Pull Request run `mix test` and `mix check` and ensure that they complete without any errors.\n5. You should request a review by at least one repo maintainer.","ref":"contributing.html#pull-request-process","title":"Pull Request Process - Contributing","type":"extras"}]}